@@ -1,9 +1,15 @@
 # coding=utf-8
-from QuickStart_Rhy.API import *
+"""
+百度云相关API
+
+Baidu cloud API
+"""
+import os
+from . import pre_check, user_lang
 try:
     import aip
 except ImportError:
-    exit('You need install: baidu-aip')
+    exit('You need to install: baidu-aip')
 
 
 class ImageDeal:
