@@ -1,9 +1,18 @@
 # coding=utf-8
-from QuickStart_Rhy.API import *
-import qiniu
+"""
+七牛云对象存储API
+
+Qiniu cloud OSS API
+"""
+from . import pre_check, dir_char, user_lang
 
 
 class QiniuOSS:
+    try:
+        import qiniu
+    except ImportError:
+        exit('You need to install "qiniu"')
+
     def __init__(self, ac_key: str = pre_check('qiniu_ac_key'),
                  sc_key: str = pre_check('qiniu_sc_key'),
                  df_bucket: str = pre_check('qiniu_bk_name')):
@@ -18,7 +27,7 @@ class QiniuOSS:
         """
         self.ac_key = ac_key
         self.sc_key = sc_key
-        self.auth = qiniu.Auth(self.ac_key, self.sc_key)
+        self.auth = QiniuOSS.qiniu.Auth(self.ac_key, self.sc_key)
         self.df_bucket = df_bucket
 
     def get_func_table(self):
@@ -48,7 +57,7 @@ class QiniuOSS:
         :return: None
         """
         tk = self.auth.upload_token(bucket if bucket else self.df_bucket, filePath.split(dir_char)[-1])
-        qiniu.put_file(tk, filePath.split(dir_char)[-1], filePath)
+        QiniuOSS.qiniu.put_file(tk, filePath.split(dir_char)[-1], filePath)
 
     def remove(self, filePath: str, bucket: str = None):
         """
@@ -60,7 +69,7 @@ class QiniuOSS:
         :param bucket: 桶名称，缺省使用self.df_bucket
         :return: None
         """
-        bk = qiniu.BucketManager(self.auth)
+        bk = QiniuOSS.qiniu.BucketManager(self.auth)
         bk.delete(bucket if bucket else self.df_bucket, filePath)
 
     def copy_url(self, filePath: str, bucket: str = None):
@@ -73,7 +82,7 @@ class QiniuOSS:
         :param bucket: 桶名称，缺省使用self.df_bucket
         :return: None
         """
-        bk = qiniu.BucketManager(self.auth)
+        bk = QiniuOSS.qiniu.BucketManager(self.auth)
         bk.fetch(filePath, bucket if bucket else self.df_bucket, filePath.split('/')[-1])
 
     def get_bucket_url(self, bucket: str = None):
@@ -88,11 +97,10 @@ class QiniuOSS:
         import requests
         bucket = bucket if bucket else self.df_bucket
         url = 'http://api.qiniu.com/v6/domain/list?tbl=%s' % bucket
-        headers = {
+        res = requests.get(url, headers={
             "Content-Type": "application/x-www-form-urlencoded",
             "Authorization": "QBox %s" % self.auth.token_of_request(url)
-        }
-        res = requests.get(url, headers=headers)
+        })
         if res.status_code == requests.codes.ok:
             return res.json()
         else:
@@ -108,14 +116,14 @@ class QiniuOSS:
         :return: None
         """
         from prettytable import PrettyTable
-        bk = qiniu.BucketManager(self.auth)
+        bk = QiniuOSS.qiniu.BucketManager(self.auth)
         ret = bk.list(bucket if bucket else self.df_bucket)
         if not ret[1]:
             print("ERROR!" if user_lang != 'zh' else '错误!')
             exit(0)
         root_url = 'http://' + self.get_bucket_url(bucket)[0] + '/'
         ret = ret[0]['items']
-        from QuickStart_Rhy.NetTools.NormalDL import size_format
+        from ..NetTools.NormalDL import size_format
         tb = PrettyTable(['File', 'Size'] if user_lang != 'zh' else ['文件', '体积'])
         for i in ret:
             tb.add_row([i['key'], size_format(i['fsize'], True)])
@@ -132,7 +140,7 @@ class QiniuOSS:
         :param bucket: 桶名称，缺省使用self.df_bucket
         :return: None
         """
-        from QuickStart_Rhy.NetTools.NormalDL import normal_dl
+        from ..NetTools.NormalDL import normal_dl
         bucket = bucket if bucket else self.df_bucket
         root_url = self.get_bucket_url(bucket)[0]
         if root_url:
