@@ -1,5 +1,10 @@
 # coding=utf-8
-from QuickStart_Rhy.API import *
+"""
+一些可以轻易实现的API
+
+Some APIs that can be easily implemented
+"""
+from . import *
 import requests
 
 
@@ -69,7 +74,7 @@ def smms(filePath: str):
         img_set = {}
         with open(path, 'r') as fp:
             ct = fp.read()
-        aims = re.findall('!\[.*?\]\((.*?)\)', ct, re.M)
+        aims = re.findall('!\[.*?]\((.*?)\)', ct, re.M) + re.findall('<img.*?src="(.*?)".*?>', ct, re.M)
         for aim in aims:
             raw_path = aim
             aim = aim.replace('~', _user_path)
@@ -165,3 +170,39 @@ def pasteme(key: str = '100', password: str = '', mode: str = 'get'):
             print(json.loads(r.content))
         else:
             print('post failed' if user_lang != 'zh' else '发送失败')
+
+
+def imgs_in_url(url: str):
+    """
+    提取url中的img标签链接
+
+    Extract img tag links from url
+
+    :param url:
+    :return:
+    """
+    from .. import headers
+    html = requests.get(url, headers=headers)
+    if html.status_code != requests.codes.ok:
+        print('Failed')
+        return
+    import re
+    from ..ImageTools.ImagePreview import image_preview
+
+    imgs = re.findall('<img.*?src="(.*?)".*?>', html.text)
+    a_ls = re.findall('<a.*?href="(.*?)".*?>', html.text)
+    for i in a_ls:
+        aim = i.lower()
+        for j in ['.png', '.jpg', 'jpeg']:
+            if j in aim:
+                imgs.append(i)
+                break
+    for url in imgs:
+        if not url.startswith('http') or url.endswith('svg'):
+            continue
+        print('[Link]' if user_lang != 'zh' else '[链接]', url[:100] + ('' if len(url) <= 100 else '...'))
+        if system == 'darwin':
+            try:
+                image_preview(url, True)
+            except Exception as e:
+                print('[Error]' if user_lang != 'zh' else '[错误]', repr(e))
