@@ -1,9 +1,18 @@
 # coding=utf-8
-from QuickStart_Rhy.API import *
+"""
+腾讯云相关API
+
+Tencent cloud API
+"""
+import json
+from . import pre_check, user_lang, dir_char
 
 
 class TxCOS:
-    import qcloud_cos
+    try:
+        import qcloud_cos
+    except ImportError:
+        exit('You need to install "cos-python-sdk-v5", "tencentcloud-sdk-python"')
 
     def __init__(self):
         """
@@ -62,7 +71,7 @@ class TxCOS:
         :param bucket: 桶名称，缺省使用self.df_bucket
         :return: None
         """
-        from QuickStart_Rhy.NetTools.NormalDL import normal_dl
+        from ..NetTools.NormalDL import normal_dl
         bucket = bucket if bucket else self.df_bucket
 
         url = self.cdn_url + filename \
@@ -92,7 +101,7 @@ class TxCOS:
         :param bucket: 桶名称，缺省使用self.df_bucket
         :return: None
         """
-        from QuickStart_Rhy.NetTools.NormalDL import size_format
+        from ..NetTools.NormalDL import size_format
         from prettytable import PrettyTable
         bucket = bucket if bucket else self.df_bucket
         ls = self.client.list_objects(Bucket=bucket)['Contents']
@@ -131,7 +140,8 @@ class Translate:
         clientProfile.httpProfile = http_profile
         self.client = Translate.tmt_client.TmtClient(cred, region, clientProfile)
 
-    def langdetect(self, text: str) -> str:
+    @staticmethod
+    def langdetect(text: str) -> str:
         """
         获取文本的语言类型
 
@@ -142,20 +152,26 @@ class Translate:
         """
         return Translate.detect(text)
 
-    def translate(self, text: str) -> dict:
+    def translate(self, text: str, from_lang: str = None, to_lang: str = user_lang) -> str:
         """
         翻译文本至默认语言
 
         Translate text to the default language
 
+        :param from_lang: 文本语言
+        :param to_lang: 目标语言
         :param text: 文本
         :return: 翻译结果
         """
         req = Translate.models.TextTranslateRequest()
         req.from_json_string(json.dumps({
             "SourceText": text,
-            "Source": self.langdetect(text),
-            "Target": user_lang,
+            "Source": self.langdetect(text) if not from_lang else from_lang,
+            "Target": to_lang,
             "ProjectId": 0
         }))
         return json.loads(self.client.TextTranslate(req).to_json_string())['TargetText']
+
+
+def translate(text: str, from_lang: str = None, to_lang: str = user_lang) -> str:
+    return Translate().translate(text, from_lang, to_lang)
