@@ -1,12 +1,16 @@
 # coding=utf-8
-from QuickStart_Rhy.API import *
+from . import *
+import os
+import json
 from urllib.parse import quote
 import requests
 
 alapi_token = pre_check('alapi_token', False)
+v1_url = "https://v1.alapi.cn/api/"
+v2_url = "https://v2.alapi.cn/api/"
 
 
-def upload_image(filePath: str, plt_type: str = 'Ali'):
+def upload_image(filePath: str, plt_type: str = ''):
     """
     上传图片或Markdown中所有的图片到多平台（免API KEY，但不保证数据安全）
 
@@ -26,9 +30,14 @@ def upload_image(filePath: str, plt_type: str = 'Ali'):
             file = [('image', open(path, 'rb'))]
         except:
             return False
-        res_json = requests.post('https://v1.alapi.cn/api/image', data=data, files=file).text \
-            if not alapi_token else \
-            requests.post('https://v1.alapi.cn/api/image', data=data, files=file, headers={'token': alapi_token}).text
+        if plt_type:
+            res_json = requests.post(v1_url + 'image', data=data, files=file).text \
+                if not alapi_token else \
+                requests.post(v1_url + 'image', data=data, files=file, headers={'token': alapi_token}).text
+        else:
+            res_json = requests.post(v1_url + 'image', files=file).text \
+                if not alapi_token else \
+                requests.post(v1_url + 'image', files=file, headers={'token': alapi_token}).text
         return json.loads(res_json)
 
     def get_path(rt, rel):
@@ -45,13 +54,17 @@ def upload_image(filePath: str, plt_type: str = 'Ali'):
             ct = fp.read()
         aims = re.findall('!\[.*?]\((.*?)\)', ct, re.M) + re.findall('<img.*?src="(.*?)".*?>', ct, re.M)
         for aim in aims:
+            if aim.startswith('http'):  # Uploaded
+                continue
             raw_path = aim
             aim = aim.replace('~', _user_path)
             aim = aim if aim.startswith(dir_char) else get_path(rt_path, aim)
             if aim not in img_dict:
+                print('Start uploading:' if user_lang != 'zh' else '正在上传:', aim,
+                      '\nResult:' if user_lang != 'zh' else '\n结果:')
                 res_dict = post_img(aim)
                 if not res_dict:
-                    res_tb.add_row([aim.split(dir_char)[-1], 'No File', ''])
+                    res_tb.add_row([aim.split(dir_char)[-1], 'No File' if user_lang != 'zh' else '无文件', ''])
                     img_dict[aim] = False
                 else:
                     try:
@@ -60,16 +73,18 @@ def upload_image(filePath: str, plt_type: str = 'Ali'):
                         res_tb.add_row([aim.split(dir_char)[-1], res_dict['code'], res_dict['msg']])
                         img_dict[aim] = False
                     else:
+                        print(res_dict)
                         res_tb.add_row([aim.split(dir_char)[-1], res_dict['code'],
                                         res_dict['msg'] if res_dict['code'] != 200 else (
-                                        res_dict['data']['url'][res_plt]
-                                        if res_dict['data']['url'][res_plt].lower() != 'null'
-                                        else res_plt + ' failed')])
+                                            res_dict['data']['url'][res_plt]
+                                            if res_dict['data']['url'][res_plt]
+                                            else res_plt + ' failed')])
                         if res_dict['code'] != 200:
                             break
-                        img_dict[aim] = res_dict['data']['url'][res_plt] if res_dict['code'] != 200 else False
+                        img_dict[aim] = res_dict['data']['url'][res_plt] if res_dict['code'] == 200 else False
                 if img_dict[aim]:
-                    print('replacing img: "{}" with "{}"'.format(raw_path, img_dict[aim]))
+                    print('replacing img:' if user_lang != 'zh' else '替换路径',
+                          '"{}" with "{}"'.format(raw_path, img_dict[aim]))
                     ct = ct.replace(raw_path, img_dict[aim])
         with open(path, 'w') as fp:
             fp.write(ct)
@@ -84,7 +99,7 @@ def upload_image(filePath: str, plt_type: str = 'Ali'):
             format_markdown(filePath)
         else:
             res = post_img(filePath)
-            tb = PrettyTable(['File', 'Status', 'url'])
+            tb = PrettyTable(['File', 'Status', 'url'] if user_lang != 'zh' else ['文件', '状态', '链接'])
             if not res:
                 tb.add_row([filePath.split(dir_char)[-1], 'No File', ''])
             else:
@@ -93,13 +108,16 @@ def upload_image(filePath: str, plt_type: str = 'Ali'):
                 except Exception:
                     tb.add_row([filePath.split(dir_char)[-1], res['code'], res['msg']])
                 else:
-                    tb.add_row([filePath.split(dir_char)[-1], res['code'],
-                                res['msg'] if res['code'] != 200 else (res['data']['url'][plt_type]
-                                if res['data']['url'][plt_type] else plt_type + ' failed')])
+                    tb.add_row([
+                        filePath.split(dir_char)[-1], res['code'], res['msg'] if res['code'] != 200 else (
+                                    res['data']['url'][plt_type] if res['data']['url'][plt_type]
+                                    else plt_type + ' failed'
+                        )
+                    ])
             print(tb)
 
 
-def translate(text: str, from_lang: str = None, to_lang: str = user_lang):
+def translate(text: str, from_lang: str = 'auto', to_lang: str = user_lang):
     """
     获取翻译结果
 
@@ -112,7 +130,7 @@ def translate(text: str, from_lang: str = None, to_lang: str = user_lang):
     """
     request_info = 'q={}&from={}&to={}'.format(quote(text, 'utf-8'), from_lang, to_lang) if from_lang \
         else 'q={}&to={}'.format(quote(text, 'utf-8'), to_lang)
-    res = requests.post('https://v1.alapi.cn/api/fanyi', data=request_info,
+    res = requests.post(v1_url + 'fanyi', data=request_info,
                         headers={'Content-Type': "application/x-www-form-urlencoded", 'token': alapi_token}
                         if alapi_token else {'Content-Type': 'application/x-www-form-urlencoded'})
     if res.status_code == requests.codes.ok:
@@ -133,8 +151,8 @@ def bili_cover(url: str):
     :return:
     """
     import re
-    from QuickStart_Rhy.NetTools.NormalDL import normal_dl
-    res = requests.post('https://v1.alapi.cn/api/bbcover', data='c='+url,
+    from ..NetTools.NormalDL import normal_dl
+    res = requests.post(v1_url + 'bbcover', data='c=' + url,
                         headers={'Content-Type': 'application/x-www-form-urlencoded', 'token': alapi_token}
                         if alapi_token else {'Content-Type': 'application/x-www-form-urlencoded'})
     if res.status_code == requests.codes.ok:
@@ -150,6 +168,10 @@ def bili_cover(url: str):
         print('[INFO ]' if user_lang != 'zh' else '[简介]', end='\n\t')
         print(res['description'], end='\n\n')
         normal_dl(res['cover'], res['title'] + '.' + res['cover'].split('.')[-1])
+        if system == 'darwin':
+            from ..ImageTools.ImagePreview import image_preview
+            from PIL import Image
+            image_preview(Image.open(res['title'] + '.' + res['cover'].split('.')[-1]))
     else:
         print(("[ERROR] Get cover with: %s failed" if user_lang != 'zh' else '[错误] 下载封面: %s 失败') % url)
 
@@ -161,20 +183,20 @@ def ip_info(ip: str):
     Get IP operator, geographic location and other data
 
     :param ip: ipv4, ipv6, empty means current machine
-    :return: data dict
+    :return: data dict {ip, isp, pos | ERROR MESSAGE, location | ERROR code}
     """
-    res = requests.post('https://v1.alapi.cn/api/ip', data="ip=%s&format=json" % ip,
+    res = requests.post(v1_url + 'ip', data="ip=%s&format=json" % ip,
                         headers={'Content-Type': "application/x-www-form-urlencoded", 'token': alapi_token}
                         if ip and alapi_token else {'Content-Type': 'application/x-www-form-urlencoded'}
                         if ip else headers.update({'token': alapi_token} if alapi_token else headers))
     try:
         res = json.loads(res.text)
         if res['code'] != 200:
-            return [ip, '', res['msg'], '{code, %s}' % res['code']]
+            return {'ip': ip, 'isp': '', 'pos': res['msg'], 'location': '{code, %s}' % res['code']}
         return res['data']
-    except :
-        print(res.text)
-        return [ip, '', '网络错误', '{code, %s}' % res.status_code]
+    except:
+        return {'ip': ip, 'isp': '', 'pos': 'Network Error'
+                if user_lang != 'zh' else '网络错误', 'location': '{code, %s}' % res.status_code}
 
 
 def garbage_classification(query_ls: list):
@@ -186,8 +208,9 @@ def garbage_classification(query_ls: list):
     :param query_ls: 待查询的垃圾列表 | garbage list
     :return: 查询结果的字符串表格 | string table
     """
+
     def fmt_string(string, pre_num):
-        return '\n' * pre_num + '\n'.join([string[i: i+10] for i in range(0, len(string), 10)])
+        return '\n' * pre_num + '\n'.join([string[i: i + 10] for i in range(0, len(string), 10)])
 
     import prettytable
     import math
@@ -198,7 +221,7 @@ def garbage_classification(query_ls: list):
             first_flag = False
         else:
             table.add_row(['-'] * 4)
-        res = requests.post("https://v1.alapi.cn/api/lajifenlei", data="name={}".format(quote(query_el, 'utf-8')),
+        res = requests.post(v1_url + "lajifenlei", data="name={}".format(quote(query_el, 'utf-8')),
                             headers={'Content-Type': "application/x-www-form-urlencoded", 'token': alapi_token}
                             if alapi_token else {'Content-Type': 'application/x-www-form-urlencoded'})
         if res.status_code == requests.codes.ok:
@@ -213,7 +236,7 @@ def garbage_classification(query_ls: list):
                 max_row = max(half_rows)
                 half_rows = [max_row - i for i in half_rows]
                 table.add_row([fmt_string(query_el, half_rows[0]),
-                               fmt_string(['可回收', '有害', '厨余(湿)', '其他(干)'][res['type']-1], half_rows[1]),
+                               fmt_string(['可回收', '有害', '厨余(湿)', '其他(干)'][res['type'] - 1], half_rows[1]),
                                fmt_string(res['explain'], half_rows[2]), fmt_string(res['tip'], half_rows[3])])
             except IndexError:
                 table.add_row([fmt_string(query_el, 0), 'Unknown', '未知垃圾', '未知垃圾'])
@@ -231,7 +254,7 @@ def short_video_info(url: str):
     :param url: 短视频分享链接 | Short video sharing link
     :return:
     """
-    res = requests.post("https://v1.alapi.cn/api/video/url", data="url={}".format(quote(url, 'utf-8')),
+    res = requests.post(v1_url + "video/url", data="url={}".format(quote(url, 'utf-8')),
                         headers={'Content-Type': "application/x-www-form-urlencoded", 'token': alapi_token}
                         if alapi_token else {'Content-Type': "application/x-www-form-urlencoded"})
     try:
@@ -239,7 +262,7 @@ def short_video_info(url: str):
         if res['code'] != 200:
             return False, {'title': res['msg'], 'cover_url': 'None', 'video_url': 'None', 'source': res['code']}
         return True, res['data']
-    except :
+    except:
         return False, {'title': '网络错误' if user_lang == 'zh' else 'Network Error',
                        'cover_url': 'None', 'video_url': 'None', 'source': 'Unknown'}
 
@@ -252,7 +275,7 @@ def acg():
 
     :return: acg image link
     """
-    res = requests.post('https://v1.alapi.cn/api/acg', data='format=json',
+    res = requests.post(v2_url + 'acg', data='format=json',
                         headers={'Content-Type': "application/x-www-form-urlencoded", 'token': alapi_token}
                         if alapi_token else {'Content-Type': "application/x-www-form-urlencoded"})
     try:
@@ -260,5 +283,44 @@ def acg():
         if res['code'] != 200:
             return False, res['msg'], 0, 0
         return True, res['data']['url'], res['data']['width'], res['data']['height']
-    except :
+    except:
         return False, ('Network Error' if user_lang != 'zh' else '网络错误'), 0, 0
+
+
+def bingImg():
+    """
+    随机获取一张bing图片链接
+
+    Get a link to a bing picture at random
+    :return: image link
+    """
+    res = requests.post(v1_url + 'bing', data='format=json',
+                        headers={'Content-Type': "application/x-www-form-urlencoded", 'token': alapi_token}
+                        if alapi_token else {'Content-Type': "application/x-www-form-urlencoded"})
+    try:
+        res = json.loads(res.text)
+        if res['code'] != 200:
+            return False, res['msg'], ''
+        return True, res['data']['url'], res['data']['copyright']
+    except:
+        return False, ('Network Error' if user_lang != 'zh' else '网络错误'), ''
+
+
+def kdCheck(kd_number: str):
+    """
+    查询中国快递
+
+    Inquire about China Express
+
+    :param kd_number: 快递单号 | courier number
+    :return: bool, list
+    """
+    res = requests.post(v1_url + 'kd', data="number=%s" % kd_number,
+                        headers={'Content-Type': 'application/x-www-form-urlencoded', 'token': alapi_token})
+    try:
+        res = json.loads(res.text)
+        if res['code'] != 200:
+            return False, 0, res['msg']
+        return True, res['data']['status'], res['data']['info']
+    except:
+        return False, 0, '[ERROR] 网络错误 | Network Error'
