@@ -1,10 +1,65 @@
 # coding=utf-8
+"""
+qs的网络工具库
+
+The network tool library of QS
+"""
+import socket
 import requests
 from requests.exceptions import RequestException
-from QuickStart_Rhy import headers
+from .. import headers
 
 
-def is_mac(addr: str):
+def is_ipv4(ip: str) -> bool:
+    """
+    判断ip是否为可连接的ipv4
+
+    Determine whether the IP is a connectable IPv4
+    :param ip: like 8.8.8.8 etc.
+    :return: bool
+    """
+    try:
+        socket.inet_pton(socket.AF_INET, ip)
+    except AttributeError:  # no inet_pton here, sorry
+        try:
+            socket.inet_aton(ip)
+        except socket.error:
+            return False
+        return ip.count('.') == 3
+    except socket.error:  # not a valid ip
+        return False
+    return True
+
+
+def is_ipv6(ip: str) -> bool:
+    """
+    判断ip是否为可连接的ipv6
+
+    Determine whether the IP is a connectable IPv6
+    :param ip: like fe80::1862:5a79:a8a0:aae5 etc.
+    :return: bool
+    """
+    try:
+        socket.inet_pton(socket.AF_INET6, ip)
+    except socket.error:  # not a valid ip
+        return False
+    return True
+
+
+def is_ip(ip: str) -> bool:
+    """
+    判断ip是否为可连接的
+
+    Determine whether the IP is a connectable
+    :param ip: like fe80::1862:5a79:a8a0:aae5, 8.8.8.8 etc.
+    :return: bool
+    """
+    if ip == 'localhost':
+        return True
+    return is_ipv4(ip) or is_ipv6(ip)
+
+
+def is_mac(addr: str) -> bool:
     """
     检查addr是否为mac地址
 
@@ -25,7 +80,7 @@ def is_mac(addr: str):
     return True
 
 
-def check_one_page(url: str):
+def check_one_page(url: str) -> bool:
     """
     检查url是否可访问
 
@@ -41,7 +96,7 @@ def check_one_page(url: str):
         return False
 
 
-def formatUrl(try_url: str):
+def formatUrl(try_url: str) -> str:
     """
     为url添加https或http使其能被访问
 
@@ -60,7 +115,21 @@ def formatUrl(try_url: str):
     return res_url
 
 
-def get_ip():
+def open_url(url: str):
+    """
+    使用默认浏览器打开url
+
+    Open url using the default browser
+
+    :param url:
+    :return:
+    """
+    import webbrowser as wb
+    url = formatUrl(url)
+    wb.open_new_tab(url)
+
+
+def get_ip() -> str:
     """
     获取本机ip
 
@@ -79,7 +148,7 @@ def get_ip():
         return socket.gethostbyname(socket.gethostname())
 
 
-def size_format(sz: int, align: bool = False):
+def size_format(sz: int, align: bool = False) -> str:
     """
     格式化文件大小显示
 
@@ -99,7 +168,7 @@ def size_format(sz: int, align: bool = False):
         return '%.2f B' % sz if not align else '%7.2f B' % sz
 
 
-def get_ip_info():
+def get_ip_info() -> dict:
     """
     通过ip-api获取本机ip信息
 
@@ -112,10 +181,10 @@ def get_ip_info():
     if res.status_code == requests.codes.ok:
         return json.loads(res.text)
     else:
-        return None
+        return {}
 
 
-def get_fileinfo(url: str, proxy: str = ''):
+def get_fileinfo(url: str, proxy: str = '') -> (str, str, requests.Response):
     """
     获取待下载的文件信息
 
@@ -123,7 +192,7 @@ def get_fileinfo(url: str, proxy: str = ''):
 
     :param url: 文件url
     :param proxy: 代理
-    :return: 真实url，文件名，http头部信息
+    :return: 真实url，文件名，http头部信息 (headers中键值均为小写)
     """
     import re
     import os
@@ -133,14 +202,15 @@ def get_fileinfo(url: str, proxy: str = ''):
     } if proxy else {}
     try:
         res = requests.head(url, headers=headers, proxies=proxies)
-    except Exception as e:
-        return False, False, False
+    except:
+        return '', '', None
     while res.status_code == 302 or res.status_code == 301:
-        url = res.headers['Location']
+        url = {i[0]: i[1] for i in res.headers.lower_items()}['location']
         res = requests.head(url, headers=headers, proxies=proxies)
-    if 'Content-Disposition' in res.headers:
+    res.headers = {i[0]: i[1] for i in res.headers.lower_items()}
+    if 'content-disposition' in res.headers:
         try:
-            filename = re.findall('filename=(.*?);', res.headers['Content-Disposition'])[0]
+            filename = re.findall('filename=(.*?);', res.headers['content-disposition'])[0]
         except IndexError:
             from urllib.parse import urlparse
             filename = os.path.basename(urlparse(url).path.strip('/'))
